@@ -1,6 +1,6 @@
 from enum import Enum
+import requests
 from typing import Any, List, Optional
-from xmlrpc.client import boolean
 from pydantic import BaseModel
 from syncari.models.core import Connection, Record
 from syncari.models.schema import Schema
@@ -10,7 +10,7 @@ class RequestType(Enum):
         Identifies all types of synapse requests
     """
     SYNAPSE_INFO = 'SYNAPSE_INFO'
-    INIT = 'INIT'
+    CONNECT = 'CONNECT'
     REFRESH_TOKEN = 'REFRESH_TOKEN'
     GET_ACCESS_TOKEN = 'GET_ACCESS_TOKEN'
     DESCRIBE = 'DESCRIBE'
@@ -86,3 +86,13 @@ class WebhookRequest(BaseModel):
     """
     body: str
     headers: Optional[dict]
+
+class ErrorResponse(BaseModel):
+    response: requests.models.Response
+    message: str
+        
+    class Config:
+        """
+            allow for object validation workaround
+        """
+        arbitrary_types_allowed = True
\ No newline at end of file
