@@ -8,7 +8,6 @@ from syncari.models.core import (AuthConfig, Connection, AuthType,
 from syncari.models.request import (DescribeRequest,
     Request, Response, SyncRequest, Watermark, WebhookRequest, RequestType)
 from syncari.rest.client import SyncariRestClient
-from syncari.router import Router
 from syncari.models.schema import Schema
 
 from syncari.synapse.abstract_synapse import Synapse
@@ -26,16 +25,10 @@ class MockSynapse(SimpleRestSynapse):
         mock_values = {'name':req_type.name}
         return Response(body=json.dumps(mock_values))
 
-    def init(self):
-        init_connection_response = InitConnectionInfo(connection=self.request.connection)
+    def connect(self):
+        init_connection_response = InitConnectionInfo(connection=self.connection)
         return Response(body=init_connection_response.json())
 
-    def refresh_token(self):
-        return None
-
-    def get_access_token(self):
-        return None
-
     def synapse_info(self):
         return Response(body=SynapseInfo(
             name='test_synapse',category='crm',
@@ -75,9 +68,6 @@ class MockSynapse(SimpleRestSynapse):
         self.__print(self.process_webhook.__name__, self.request)
         return self.__get_mock_response(RequestType.PROCESS_WEBHOOK)
 
-    def get_rest_client(self):
-        return SyncariRestClient(self.request.connection.endpoint, {'api_token':self.request.connection.authConfig.accessToken}, None)
-
     def process_single_row(self):
         return super().process_single_row()
 
@@ -93,7 +83,7 @@ class MockErrorSynapse(SimpleRestSynapse):
         mock_values = {'error':'error_str_' + req_type.name}
         return Response(body=json.dumps(mock_values))
 
-    def init(self):
+    def connect(self):
         return None
 
     def synapse_info(self):
@@ -131,9 +121,6 @@ class MockErrorSynapse(SimpleRestSynapse):
         self.__print(self.process_webhook.__name__, self.request)
         return self.__get_mock_error_response(RequestType.PROCESS_WEBHOOK)
 
-    def get_rest_client(self):
-        return SyncariRestClient(self.request.connection.endpoint, {'api_token':self.request.connection.authConfig.accessToken}, None)
-
     def process_single_row(self):
         return super().process_single_row()
 
@@ -166,26 +153,22 @@ def __get_process_webook_request():
         body=WebhookRequest(body=json.dumps([{'key':'value'}])))
 
 def __assert_route(synapse_request):
-    synapse = MockSynapse(synapse_request.json(), 'id', 'data')
-    router = Router(synapse)
-    resp = router.route()
+    rest_client = SyncariRestClient(synapse_request.connection.endpoint, {'api_token':synapse_request.connection.authConfig.accessToken})
+    synapse = MockSynapse(synapse_request.json(), rest_client, 'id', 'data')
+    resp = synapse.execute()
     print(resp)
     assert resp is not None
-    #assert resp.type is synapse.request.type
-    #assert resp.status is HTTPStatus.OK
     expected = json.loads(resp.body)
-    assert expected['name'].casefold() == synapse.request.type.name.casefold()
+    assert expected['name'].casefold() == synapse.request_type.name.casefold()
 
 def __assert_error_route(synapse_request):
-    synapse = MockErrorSynapse(synapse_request.json(), 'id', 'data')
-    router = Router(synapse)
-    resp = router.route()
+    rest_client = SyncariRestClient(synapse_request.connection.endpoint, {'api_token':synapse_request.connection.authConfig.accessToken})
+    synapse = MockErrorSynapse(synapse_request.json(), rest_client, 'id', 'data')
+    resp = synapse.execute()
     print(resp)
     assert resp is not None
-    #assert resp.type is synapse.request.type
-    #assert resp.status is HTTPStatus.BAD_REQUEST
     expected = json.loads(resp.body)
-    assert expected['error'].casefold() == 'error_str_' + synapse.request.type.name.casefold()
+    assert expected['error'].casefold() == 'error_str_' + synapse.request_type.name.casefold()
 
 def test_describe_route():
     __assert_route(__get_describe_synapse_request())
@@ -225,31 +208,30 @@ def test_process_webook_request():
 
 def test_invalid_synapse_object():
     with pytest.raises(Exception):
-        router = Router(InvalidSynapse())
-        resp = router.route()
+        resp = InvalidSynapse().execute()
         assert resp is not None
 
 def test_get_synapse_info():
     synapse_request = Request(type=RequestType.SYNAPSE_INFO,
         connection=get_connection(),
         body=None)
-    synapse = MockSynapse(synapse_request.json(), 'id', 'data')
-    router = Router(synapse)
-    resp = router.route()
+    rest_client = SyncariRestClient(synapse_request.connection.endpoint, {'api_token':synapse_request.connection.authConfig.accessToken})
+    synapse = MockSynapse(synapse_request.json(), rest_client, 'id', 'data')
+    resp = synapse.execute()
     assert resp is not None
 
-def test_init():
-    synapse_request = Request(type=RequestType.INIT,
+def test_connect():
+    synapse_request = Request(type=RequestType.CONNECT,
         connection=get_connection(),
         body=None)
-    synapse = MockSynapse(synapse_request.json(), 'id', 'data')
-    router = Router(synapse)
-    resp = router.route()
+    rest_client = SyncariRestClient(synapse_request.connection.endpoint, {'api_token':synapse_request.connection.authConfig.accessToken})
+    synapse = MockSynapse(synapse_request.json(), rest_client, 'id', 'data')
+    resp = synapse.execute()
     assert resp is not None
     
 
 def get_connection():
-    authConfig=AuthConfig(endpoint='http://endpoint.com')
-    connection = Connection(id='1', name='name', authConfig=authConfig, idFieldName='idfield', watermarkFieldName='watermarkfield', endpoint='http://endpoint.com',
+    authConfig=AuthConfig(endpoint='http://endpoint.com/')
+    connection = Connection(id='1', name='name', authConfig=authConfig, idFieldName='idfield', watermarkFieldName='watermarkfield', endpoint='http://endpoint.com/',
     createdAtFieldName='createdfield', updatedAtFieldName='updatedfield', oAuthRedirectUrl='http://redirect.com')
     return connection
